"use strict";

let ws;

function send(m) {
    ws.send(JSON.stringify(m));
}

function connect() {
    ws = new WebSocket(
        ((window.location.protocol === "https:") ? "wss://" : "ws://") +
            window.location.host + "/chat/ws");
    ws.onerror = function(e) {
        addEntry(e.error ? e.error.toString() : e.toString(), true);
    };

    ws.onopen = function(e) {
        send({
            type: 'subscribe',
            count: 50,
        });
    };

    ws.onclose = function(e) {
        addEntry('disconnected', true);
    };

    ws.onmessage = function(e) {
        let m = JSON.parse(e.data);
        switch(m.type) {
        case 'message':
            addEntry(m.message.body);
            break;
        case 'messages':
            if(m.messages) {
                for(let i = 0; i < m.messages.length; i++)
                    addEntry(m.messages[i].body);
            }
            break;
        case 'error':
            addEntry(m.error, true);
            break;
        case 'ok':
            break;
        default:
            addEntry(m.error, 'Unknown message type ' + m.type);
            break;
        }
    };
}

function addEntry(s, isError) {
    let p = document.createElement('p');
    p.textContent = s;
    if(isError)
        p.classList.add('error');
    document.getElementById('box').appendChild(p);
}

async function handleInput(e) {
    e.preventDefault();
    var input = document.getElementById('input');
    var inputform = document.getElementById('inputform');
    var value = input.value;
    send({
        type: 'post',
        message: {
            body: value,
        }
    });
    input.value = '';
}

document.getElementById("inputform").onsubmit = handleInput;
connect();
